@@ -13,6 +13,7 @@ def cutoff_sampling(
     variable_list=None,
     min_growth=False,
     fraction_of_optim=0.9,
+    solver_name=None,
 ):
     """Implements the quadratic constraint using repeated sampling on the surface of ellipsoid. Exits when 100 consecutive samples represent better solution. We fix the component sphere variables lb & ub to the sampled covariance and solve the problem.
 
@@ -28,6 +29,8 @@ def cutoff_sampling(
         Boolean, to add minimum growth constraint or not, by default False
     fraction_of_optim : float, optional
         fraction of original growth/flux value, by default 0.9
+    solver_name : str, optional
+        preferred solver, if not specified and has more than one solver uses the same solver order as cobra, by default 0.9
 
     Returns
     -------
@@ -39,7 +42,11 @@ def cutoff_sampling(
     ValueError
         Initial check to see if model is feasible with given constraints
     """
-    model = preprocess_model(model_variability)
+    model_copy = copy(model_variability)  # Copy the original model for sampling
+    model = preprocess_model(model_copy)  # Preprocess the model to add sphere variables
+
+    if solver_name:
+        model.solver = solver_name
 
     # Retrieve small and large sphere variables
     small_sphere_vars = [
@@ -80,6 +87,13 @@ def cutoff_sampling(
         np.zeros((len(variables), 2)), columns=["minimum", "maximum"]
     )
 
+    Whole_ranges = DataFrame(
+        {
+            "minimum": Series(index=variables, data=np.empty(len(variables))),
+            "maximum": Series(index=variables, data=np.empty(len(variables))),
+        }
+    )
+
     n_improvement, total_samples = (0, 0)
     while n_improvement < cutoff:
         total_samples = total_samples + 1
@@ -121,8 +135,10 @@ def cutoff_sampling(
             else:
                 n_improvement = n_improvement + 1
 
+            Whole_ranges = concat([Whole_ranges, tva_ranges], axis=1)
+
         lastone = tva_ranges
-    return representative_ranges, total_samples
+    return representative_ranges, Whole_ranges, total_samples
 
 
 def gev_sampling(
@@ -131,6 +147,7 @@ def gev_sampling(
     variable_list=None,
     min_growth=False,
     fraction_of_optim=0.9,
+    solver_name=None,
 ):
     """Implements the quadratic constraint using repeated sampling on the surface of ellipsoid. After sampling for fixed number of times, we use generalised extreme value distribution to predict the possible extremum of the distribution. We fix the component sphere variables lb & ub to the sampled covariance and solve the problem.
 
@@ -146,13 +163,20 @@ def gev_sampling(
         Boolean, to add minimum growth constraint or not, by default False
     fraction_of_optim : float, optional
         fraction of original growth/flux value, by default 0.9
+    solver_name : str, optional
+        preferred solver, if not specified and has more than one solver uses the same solver order as cobra, by default 0.9
 
     Returns
     -------
     pd.DataFrame
         pd.DataFrame of ranges of values for the variables
     """
-    model = preprocess_model(model_variability)
+    model_copy = copy(model_variability)
+
+    model = preprocess_model(model_copy)
+
+    if solver_name:
+        model.solver = solver_name
 
     # Retrieve small and large sphere variables
     small_sphere_vars = [
@@ -228,7 +252,7 @@ def gev_sampling(
         if tva_ranges.empty or tva_ranges.isnull().all()["maximum"]:
             total_samples = total_samples - 1
             continue
-
+        # print(total_samples, tva_ranges)
         Whole_ranges = concat([Whole_ranges, tva_ranges], axis=1)
 
     for var in variables:
@@ -244,7 +268,7 @@ def gev_sampling(
         }
     )
 
-    return representative_ranges
+    return representative_ranges, Whole_ranges
 
 
 def sampling(
