@@ -10,10 +10,15 @@ from ..util.thermo_constants import *
 def generate_n_sphere_sample(n_variables):
     """Generates unit n-sphere sample. Works by picking random sample from normal distribution and normalized by radius.
 
-    :param n_variables: Dimension of the n-sphere.
-    :type n_variables: float
-    :return: unit n-sphere sample
-    :rtype: np.ndarray
+    Parameters
+    ----------
+    n_variables : int
+        number of variables, dimension of the required sphere
+
+    Returns
+    -------
+    np.array
+        n-sphere sample with required dimensions
     """
     # n-sphere sample from N(0,1)
     random_sample = np.random.normal(loc=0, scale=1.0, size=(n_variables))
@@ -29,10 +34,15 @@ def generate_ellipsoid_sample(cholesky):
     N(mu,var) = mu + A @ N(0,1)
     A@A' = var, A is cholesky matrix
 
-    :param cholesky: cholesky matrix
-    :type cholesky: np.ndarray
-    :return: ellipsoid sample
-    :rtype: np.ndarray
+    Parameters
+    ----------
+    cholesky : np.ndarray
+        cholesky matrix
+
+    Returns
+    -------
+    np.array
+        numpy array containing ellipsoid sample with cholesky matrix length
     """
 
     n_dimensions = len(cholesky)
@@ -44,11 +54,25 @@ def generate_ellipsoid_sample(cholesky):
 
 
 def preprocess_model(model):
+    """This function preprocess the model for the sampling on the surface of the ellipsoid method. We first remove the existing dG constraint and associated error variables. Then add the sphere variables. Depending on the variance range of covariance matrix, we split the sphere variables in two ellipsoids.
+
+    Parameters
+    ----------
+    model : multitfa.core.tmodel
+        multitfa model, updated
+
+    Returns
+    -------
+    multitfa.core.tmodel
+        preprocessed model with modified thermo constraints to work on sampling approach
+    """
     # First remove the delG constraint and associated variables, we will add them later
     remove_vars = [
         var
         for var in model.variables
-        if var.name.startswith("component_") or var.name.startswith("dG_err_")
+        if var.name.startswith("component_")
+        or var.name.startswith("dG_err_")
+        or var.name.startswith("Sphere_")
     ]
     remove_cons = [
         cons
@@ -56,6 +80,9 @@ def preprocess_model(model):
         if cons.name.startswith("delG_") or cons.name.startswith("std_dev_")
     ]
 
+    # Remove the variables and constraints from the model
+    model.remove_cons_vars(remove_cons + remove_vars)
+
     # Pick indices of components present in the current model
     model_component_indices = [
         i
