@@ -4,9 +4,7 @@ import numpy as np
 from pandas import DataFrame, Series
 
 
-def variability(
-    model_variability, variable_list=None, min_growth=False, fraction_of_optim=0.9
-):
+def variability(model_variability, variable_list=None):
     """Perform thermodynamic variability analysis.
 
     Determine the minimum and maximum values for the input variables (Flux, Gibbs free
@@ -19,10 +17,7 @@ def variability(
         multitfa model after thermodynamic constraints are added
     variable_list : List, optional
         List of variables to perform TVA on, by default None
-    min_growth : bool, optional
-        if min growth contraint is needed, by default False
-    fraction_of_optim : float, optional
-        fraction of initial growth, constraint, by default 0.9
+
 
     Returns
     -------
@@ -44,25 +39,6 @@ def variability(
     if np.isnan(model.slim_optimize()):
         raise ValueError("model infeasible with given constraints")
 
-    if min_growth:
-        if model.solver.objective.direction == "max":
-            fva_old_objective = model.problem.Variable(
-                "fva_old_objective", lb=fraction_of_optim * model.solver.objective.value
-            )
-        else:
-            fva_old_objective = model.problem.Variable(
-                "fva_old_objective", ub=fraction_of_optim * model.solver.objective.value
-            )
-        # Add the minimal growth/production constraint
-        fva_old_obj_constraint = model.problem.Constraint(
-            model.solver.objective.expression - fva_old_objective,
-            lb=0,
-            ub=0,
-            name="fva_old_objective_constraint",
-        )
-
-        model.add_cons_vars([fva_old_obj_constraint, fva_old_objective])
-
     fluxes_min = np.empty(len(variables))
     fluxes_max = np.empty(len(variables))
     rxn_name = list()
@@ -104,9 +80,8 @@ def variability(
 def variability_legacy_gurobi(
     model_variability,
     variable_list=None,
-    min_growth=False,
-    fraction_of_optim=0.9,
     warm_start={},
+    params=False,
 ):
     """Custom function to perform TVA on MIQC problem using gurobi.
 
@@ -116,12 +91,10 @@ def variability_legacy_gurobi(
         multitfa model after thermodynamic constraints are added
     variable_list : List, optional
         List of variables to perform TVA on, by default None
-    min_growth : bool, optional
-        if min growth contraint is needed, by default False
-    fraction_of_optim : float, optional
-        fraction of initial growth, constraint, by default 0.9
     warm_start : dict, optional
         Optionally can specify warm start to speed up problem. variable name and initial solution, by default {}
+    params : Bool, optional
+        If True sets the Timelimit option to 300 sec
 
     Returns
     -------
@@ -130,83 +103,64 @@ def variability_legacy_gurobi(
     """
     from gurobipy import GRB
 
-    model = copy(model_variability)
+    gurobi_interface = model_variability.gurobi_interface.copy()
+
     if variable_list == None:
-        variables = model.gurobi_interface.getVars()
+        variables = gurobi_interface.getVars()
     else:
         variables = [var for var in variable_list]
 
-    model.gurobi_interface.optimize()
+    gurobi_interface.optimize()
 
-    if min_growth:
-        if model.solver.objective.direction == "max":
-            fva_old_objective = model.gurobi_interface.addVar(
-                name="fva_old_objective",
-                lb=fraction_of_optim * model.gurobi_interface.ObjVal,
-            )
-        else:
-            fva_old_objective = model.gurobi_interface.addVar(
-                name="fva_old_objective",
-                ub=fraction_of_optim * model.gurobi_interface.ObjVal,
-            )
-
-        # Add the minimal growth/production constraint
-        old_obj = model.gurobi_interface.getObjective()
-        model.gurobi_interface.addConstr(
-            old_obj - fva_old_objective,
-            GRB.EQUAL,
-            0,
-            name="fva_old_objective_constraint",
-        )
-
-        model.gurobi_interface.update()
+    # Set the time limit searching for solution, useful for pathlogical variables taking long time
+    if params:
+        gurobi_interface.params.TimeLimit = 300
 
     fluxes_min = np.empty(len(variables))
     fluxes_max = np.empty(len(variables))
     rxn_name = list()
 
-    rxn_ids = [rxn.id for rxn in model.reactions]
+    rxn_ids = [rxn.id for rxn in model_variability.reactions]
 
     for i in range(len(variables)):
-
         # if the variable is reactions optimize for forward - reverse variables else optimize for the variable
         if variables[i] in rxn_ids:
-            rxn = model.reactions.get_by_id(variables[i])
-            for_var = model.gurobi_interface.getVarByName(rxn.forward_variable.name)
-            rev_var = model.gurobi_interface.getVarByName(rxn.reverse_variable.name)
+            rxn = model_variability.reactions.get_by_id(variables[i])
+            for_var = gurobi_interface.getVarByName(rxn.forward_variable.name)
+            rev_var = gurobi_interface.getVarByName(rxn.reverse_variable.name)
             obj_exp = for_var - rev_var
         else:
-            obj_exp = model.gurobi_interface.getVarByName(variables[i])
+            obj_exp = gurobi_interface.getVarByName(variables[i])
 
         rxn_name.append(variables[i])
 
         # minimization
         if len(warm_start) != 0:
-            for var in model.gurobi_interface.getVars():
+            for var in gurobi_interface.getVars():
                 if var in warm_start:
                     var.Start = warm_start[var]
 
-        model.gurobi_interface.setObjective(obj_exp, GRB.MINIMIZE)
-        model.gurobi_interface.update()
-        model.gurobi_interface.optimize()
-        objective_value = model.gurobi_interface.ObjVal
+        gurobi_interface.setObjective(obj_exp, GRB.MINIMIZE)
+        gurobi_interface.update()
+        gurobi_interface.optimize()
+        objective_value = gurobi_interface.ObjVal
         fluxes_min[i] = objective_value
         # print(rxn.id, "min", objective_value)
 
         warm_start = {}
-        for var in model.gurobi_interface.getVars():
+        for var in gurobi_interface.getVars():
             if var.VarName.startswith("indicator_"):
                 warm_start[var] = var.x
 
         # maximiztion
-        for var in model.gurobi_interface.getVars():
+        for var in gurobi_interface.getVars():
             if var in warm_start:
                 var.Start = warm_start[var]
 
-        model.gurobi_interface.setObjective(obj_exp, GRB.MAXIMIZE)
-        model.gurobi_interface.update()
-        model.gurobi_interface.optimize()
-        objective_value = model.gurobi_interface.ObjVal
+        gurobi_interface.setObjective(obj_exp, GRB.MAXIMIZE)
+        gurobi_interface.update()
+        gurobi_interface.optimize()
+        objective_value = gurobi_interface.ObjVal
         fluxes_max[i] = objective_value
         # print(rxn.id, "max", objective_value)
 
@@ -227,10 +181,7 @@ from random import choices
 def variability_legacy_cplex(
     model,
     variable_list=None,
-    min_growth=False,
-    biomass_rxn=None,
-    fraction_of_optim=0.9,
-    warm_start={},
+    params=False,
 ):
     """Custom function to perform TVA on MIQC problem using gurobi.
 
@@ -240,12 +191,8 @@ def variability_legacy_cplex(
         multitfa model after thermodynamic constraints are added
     variable_list : List, optional
         List of variables to perform TVA on, by default None
-    min_growth : bool, optional
-        if min growth contraint is needed, by default False
-    fraction_of_optim : float, optional
-        fraction of initial growth, constraint, by default 0.9
-    warm_start : dict, optional
-        Optionally can specify warm start to speed up problem. variable name and initial solution, by default {}
+    params : Bool, optional
+        If True sets the Timelimit option to 300 sec and reduced the mip gap to 0.005
 
     Returns
     -------
@@ -285,6 +232,12 @@ def variability_legacy_cplex(
     cplex_model.set_warning_stream(None)
     cplex_model.set_results_stream(None)
 
+    if params:
+        # print("lol")
+        cplex_model.parameters.mip.tolerances.mipgap = 0.005
+        cplex_model.parameters.timelimit = 300
+        cplex_model.parameters.mip.limits.probetime = 300
+
     # Make shorts for sense
     max_sense = cplex_model.objective.sense.maximize
     min_sense = cplex_model.objective.sense.minimize
@@ -295,52 +248,6 @@ def variability_legacy_cplex(
         variables = [var for var in variable_list]
 
     vars_list_cplex = cplex_model.variables.get_names()
-    if min_growth:
-
-        if biomass_rxn == None:
-            raise ValueError(
-                "Please provide growth reaction name to add the minimum growth constraint"
-            )
-        # Make the biomass reaction objective
-
-        for varname in vars_list_cplex:
-            cplex_model.objective.set_linear(varname, 0)
-
-        biomass_for_name = model.reactions.get_by_id(biomass_rxn).forward_variable.name
-        biomass_rev_name = model.reactions.get_by_id(biomass_rxn).reverse_variable.name
-
-        cplex_model.objective.set_linear(
-            [(biomass_for_name, 1), (biomass_rev_name, -1)]
-        )
-
-        cplex_model.solve()
-
-        if model.solver.objective.direction == "max":
-            fva_old_objective = cplex_model.variables.add(names=["fva_old_objective"])
-            cplex_model.variables.set_lower_bounds = (
-                "fva_old_objective",
-                fraction_of_optim * cplex_model.solution.get_objective_value(),
-            )
-
-        else:
-            fva_old_objective = cplex_model.variables.add(names=["fva_old_objective"])
-            cplex_model.variables.set_upper_bounds = (
-                "fva_old_objective",
-                fraction_of_optim * cplex_model.solution.get_objective_value(),
-            )
-
-        # Add the minimal growth/production constraint
-        _ = cplex_model.linear_constraints.add(
-            lin_expr=[
-                SparsePair(
-                    ind=[biomass_for_name, biomass_rev_name, fva_old_objective],
-                    val=[1, -1, -1],
-                )
-            ],
-            senses="E",
-            rhs=[0],
-            names="min_growth",
-        )
 
     fluxes_min = np.empty(len(variables))
     fluxes_max = np.empty(len(variables))
@@ -370,14 +277,12 @@ def variability_legacy_cplex(
         cplex_model.solve()
         objective_value = cplex_model.solution.get_objective_value()
         fluxes_min[i] = objective_value
-        # print(rxn.id, "min", objective_value)
 
         # maximiztion
         cplex_model.objective.set_sense(max_sense)
         cplex_model.solve()
         objective_value = cplex_model.solution.get_objective_value()
         fluxes_max[i] = objective_value
-        # print(rxn.id, "max", objective_value)
 
     return DataFrame(
         {
