@@ -3,6 +3,7 @@ import pickle
 import string
 import tempfile
 from copy import copy, deepcopy
+from pathlib import Path
 from random import choices
 
 import optlang
@@ -28,6 +29,8 @@ cwd = os.getcwd()
 import logging
 
 
+cache_file = Path(__file__).parent.parent / "data" / "compounds_cache.pickle"
+
 logs_dir = cwd + os.sep + "logs"
 if not os.path.exists(logs_dir):
     os.makedirs(logs_dir)
@@ -36,18 +39,6 @@ logging.basicConfig(
     filename=logs_dir + os.sep + "thermo_model.log", level=logging.DEBUG
 )
 
-cache_file = os.path.normpath(
-    os.path.dirname(os.path.abspath(__file__))
-    + os.sep
-    + os.pardir
-    + os.sep
-    + os.pardir
-    + os.sep
-    + "cache"
-    + os.sep
-    + "compounds_cache.pickle"
-)
-
 
 class tmodel(Model):
     """tmodel is Class representation of thermodynamic metabolic flux analysis model. This class adds attributes and methods required for thermodynamic analysis of a COBRA model.
@@ -241,7 +232,7 @@ class tmodel(Model):
                     handle
                 )
         else:
-            metabolite_accessions = {}
+            metabolite_accessions, microspecies, mg_dissociation_data = ({}, {}, {})
 
         accessions = {}
         for metabolite in self.metabolites:
@@ -251,18 +242,21 @@ class tmodel(Model):
                 eq_accession = api.get_compound(metabolite.Kegg_id)
                 accessions[metabolite.id] = eq_accession
                 # update the cache file
-                # if eq_accession is not None:
-                #    metabolite_accessions[metabolite.Kegg_id] = eq_accession
-                #    microspecies[metabolite.Kegg_id] = eq_accession.microspecies
-                #    mg_dissociation_data[
-                #        metabolite.Kegg_id
-                #    ] = eq_accession.magnesium_dissociation_constants
+                if eq_accession is not None:
+                    metabolite_accessions[metabolite.Kegg_id] = eq_accession
+                    microspecies[metabolite.Kegg_id] = eq_accession.microspecies
+                    mg_dissociation_data[
+                        metabolite.Kegg_id
+                    ] = eq_accession.magnesium_dissociation_constants
 
-        # Re-write the cache file with updated values
-        # with open(cache_file, "wb") as handle:
-        #    pickle.dump(
-        #        [metabolite_accessions, microspecies, mg_dissociation_data], handle
-        #    )
+        # Try and update the cache file with updated values
+        try:
+            with open(cache_file, "wb") as handle:
+                pickle.dump(
+                    [metabolite_accessions, microspecies, mg_dissociation_data], handle
+                )
+        except:
+            pass
 
         return accessions
 
@@ -782,6 +776,8 @@ class tmodel(Model):
                     name="unit_normal_small_variance",
                 )
                 gurobi_model.update()
+            else:
+                sphere1_variables = []
 
             # QC for large variance components
             if len(high_variance_indices) > 0:
@@ -800,6 +796,8 @@ class tmodel(Model):
                     name="unit_normal_high_variance",
                 )
                 gurobi_model.update()
+            else:
+                sphere2_variables = []
 
             # Create a list of metabolite concentration variables
             concentration_variables = []
